%%
%% This is file `l3names.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% l3names.dtx  (with options: `names')
%% 
%% Copyright (C) 1990-2026 The LaTeX Project
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "l3kernel bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: l3names.dtx
  \__kernel_primitive:NN \                      \tex_space:D
  \__kernel_primitive:NN \/                     \tex_italiccorrection:D
  \__kernel_primitive:NN \-                     \tex_hyphen:D
  \__kernel_primitive:NN \above                 \tex_above:D
  \__kernel_primitive:NN \abovedisplayshortskip \tex_abovedisplayshortskip:D
  \__kernel_primitive:NN \abovedisplayskip      \tex_abovedisplayskip:D
  \__kernel_primitive:NN \abovewithdelims       \tex_abovewithdelims:D
  \__kernel_primitive:NN \accent                \tex_accent:D
  \__kernel_primitive:NN \adjdemerits           \tex_adjdemerits:D
  \__kernel_primitive:NN \advance               \tex_advance:D
  \__kernel_primitive:NN \afterassignment       \tex_afterassignment:D
  \__kernel_primitive:NN \aftergroup            \tex_aftergroup:D
  \__kernel_primitive:NN \atop                  \tex_atop:D
  \__kernel_primitive:NN \atopwithdelims        \tex_atopwithdelims:D
  \__kernel_primitive:NN \badness               \tex_badness:D
  \__kernel_primitive:NN \baselineskip          \tex_baselineskip:D
  \__kernel_primitive:NN \batchmode             \tex_batchmode:D
  \__kernel_primitive:NN \begingroup            \tex_begingroup:D
  \__kernel_primitive:NN \belowdisplayshortskip \tex_belowdisplayshortskip:D
  \__kernel_primitive:NN \belowdisplayskip      \tex_belowdisplayskip:D
  \__kernel_primitive:NN \binoppenalty          \tex_binoppenalty:D
  \__kernel_primitive:NN \botmark               \tex_botmark:D
  \__kernel_primitive:NN \box                   \tex_box:D
  \__kernel_primitive:NN \boxmaxdepth           \tex_boxmaxdepth:D
  \__kernel_primitive:NN \brokenpenalty         \tex_brokenpenalty:D
  \__kernel_primitive:NN \catcode               \tex_catcode:D
  \__kernel_primitive:NN \char                  \tex_char:D
  \__kernel_primitive:NN \chardef               \tex_chardef:D
  \__kernel_primitive:NN \cleaders              \tex_cleaders:D
  \__kernel_primitive:NN \closein               \tex_closein:D
  \__kernel_primitive:NN \closeout              \tex_closeout:D
  \__kernel_primitive:NN \clubpenalty           \tex_clubpenalty:D
  \__kernel_primitive:NN \copy                  \tex_copy:D
  \__kernel_primitive:NN \count                 \tex_count:D
  \__kernel_primitive:NN \countdef              \tex_countdef:D
  \__kernel_primitive:NN \cr                    \tex_cr:D
  \__kernel_primitive:NN \crcr                  \tex_crcr:D
  \__kernel_primitive:NN \csname                \tex_csname:D
  \__kernel_primitive:NN \day                   \tex_day:D
  \__kernel_primitive:NN \deadcycles            \tex_deadcycles:D
  \__kernel_primitive:NN \def                   \tex_def:D
  \__kernel_primitive:NN \defaulthyphenchar     \tex_defaulthyphenchar:D
  \__kernel_primitive:NN \defaultskewchar       \tex_defaultskewchar:D
  \__kernel_primitive:NN \delcode               \tex_delcode:D
  \__kernel_primitive:NN \delimiter             \tex_delimiter:D
  \__kernel_primitive:NN \delimiterfactor       \tex_delimiterfactor:D
  \__kernel_primitive:NN \delimitershortfall    \tex_delimitershortfall:D
  \__kernel_primitive:NN \dimen                 \tex_dimen:D
  \__kernel_primitive:NN \dimendef              \tex_dimendef:D
  \__kernel_primitive:NN \discretionary         \tex_discretionary:D
  \__kernel_primitive:NN \displayindent         \tex_displayindent:D
  \__kernel_primitive:NN \displaylimits         \tex_displaylimits:D
  \__kernel_primitive:NN \displaystyle          \tex_displaystyle:D
  \__kernel_primitive:NN \displaywidowpenalty   \tex_displaywidowpenalty:D
  \__kernel_primitive:NN \displaywidth          \tex_displaywidth:D
  \__kernel_primitive:NN \divide                \tex_divide:D
  \__kernel_primitive:NN \doublehyphendemerits  \tex_doublehyphendemerits:D
  \__kernel_primitive:NN \dp                    \tex_dp:D
  \__kernel_primitive:NN \dump                  \tex_dump:D
  \__kernel_primitive:NN \edef                  \tex_edef:D
  \__kernel_primitive:NN \else                  \tex_else:D
  \__kernel_primitive:NN \emergencystretch      \tex_emergencystretch:D
  \__kernel_primitive:NN \end                   \tex_end:D
  \__kernel_primitive:NN \endcsname             \tex_endcsname:D
  \__kernel_primitive:NN \endgroup              \tex_endgroup:D
  \__kernel_primitive:NN \endinput              \tex_endinput:D
  \__kernel_primitive:NN \endlinechar           \tex_endlinechar:D
  \__kernel_primitive:NN \eqno                  \tex_eqno:D
  \__kernel_primitive:NN \errhelp               \tex_errhelp:D
  \__kernel_primitive:NN \errmessage            \tex_errmessage:D
  \__kernel_primitive:NN \errorcontextlines     \tex_errorcontextlines:D
  \__kernel_primitive:NN \errorstopmode         \tex_errorstopmode:D
  \__kernel_primitive:NN \escapechar            \tex_escapechar:D
  \__kernel_primitive:NN \everycr               \tex_everycr:D
  \__kernel_primitive:NN \everydisplay          \tex_everydisplay:D
  \__kernel_primitive:NN \everyhbox             \tex_everyhbox:D
  \__kernel_primitive:NN \everyjob              \tex_everyjob:D
  \__kernel_primitive:NN \everymath             \tex_everymath:D
  \__kernel_primitive:NN \everypar              \tex_everypar:D
  \__kernel_primitive:NN \everyvbox             \tex_everyvbox:D
  \__kernel_primitive:NN \exhyphenpenalty       \tex_exhyphenpenalty:D
  \__kernel_primitive:NN \expandafter           \tex_expandafter:D
  \__kernel_primitive:NN \fam                   \tex_fam:D
  \__kernel_primitive:NN \fi                    \tex_fi:D
  \__kernel_primitive:NN \finalhyphendemerits   \tex_finalhyphendemerits:D
  \__kernel_primitive:NN \firstmark             \tex_firstmark:D
  \__kernel_primitive:NN \floatingpenalty       \tex_floatingpenalty:D
  \__kernel_primitive:NN \font                  \tex_font:D
  \__kernel_primitive:NN \fontdimen             \tex_fontdimen:D
  \__kernel_primitive:NN \fontname              \tex_fontname:D
  \__kernel_primitive:NN \futurelet             \tex_futurelet:D
  \__kernel_primitive:NN \gdef                  \tex_gdef:D
  \__kernel_primitive:NN \global                \tex_global:D
  \__kernel_primitive:NN \globaldefs            \tex_globaldefs:D
  \__kernel_primitive:NN \halign                \tex_halign:D
  \__kernel_primitive:NN \hangafter             \tex_hangafter:D
  \__kernel_primitive:NN \hangindent            \tex_hangindent:D
  \__kernel_primitive:NN \hbadness              \tex_hbadness:D
  \__kernel_primitive:NN \hbox                  \tex_hbox:D
  \__kernel_primitive:NN \hfil                  \tex_hfil:D
  \__kernel_primitive:NN \hfill                 \tex_hfill:D
  \__kernel_primitive:NN \hfilneg               \tex_hfilneg:D
  \__kernel_primitive:NN \hfuzz                 \tex_hfuzz:D
  \__kernel_primitive:NN \hoffset               \tex_hoffset:D
  \__kernel_primitive:NN \holdinginserts        \tex_holdinginserts:D
  \__kernel_primitive:NN \hrule                 \tex_hrule:D
  \__kernel_primitive:NN \hsize                 \tex_hsize:D
  \__kernel_primitive:NN \hskip                 \tex_hskip:D
  \__kernel_primitive:NN \hss                   \tex_hss:D
  \__kernel_primitive:NN \ht                    \tex_ht:D
  \__kernel_primitive:NN \hyphenation           \tex_hyphenation:D
  \__kernel_primitive:NN \hyphenchar            \tex_hyphenchar:D
  \__kernel_primitive:NN \hyphenpenalty         \tex_hyphenpenalty:D
  \__kernel_primitive:NN \if                    \tex_if:D
  \__kernel_primitive:NN \ifcase                \tex_ifcase:D
  \__kernel_primitive:NN \ifcat                 \tex_ifcat:D
  \__kernel_primitive:NN \ifdim                 \tex_ifdim:D
  \__kernel_primitive:NN \ifeof                 \tex_ifeof:D
  \__kernel_primitive:NN \iffalse               \tex_iffalse:D
  \__kernel_primitive:NN \ifhbox                \tex_ifhbox:D
  \__kernel_primitive:NN \ifhmode               \tex_ifhmode:D
  \__kernel_primitive:NN \ifinner               \tex_ifinner:D
  \__kernel_primitive:NN \ifmmode               \tex_ifmmode:D
  \__kernel_primitive:NN \ifnum                 \tex_ifnum:D
  \__kernel_primitive:NN \ifodd                 \tex_ifodd:D
  \__kernel_primitive:NN \iftrue                \tex_iftrue:D
  \__kernel_primitive:NN \ifvbox                \tex_ifvbox:D
  \__kernel_primitive:NN \ifvmode               \tex_ifvmode:D
  \__kernel_primitive:NN \ifvoid                \tex_ifvoid:D
  \__kernel_primitive:NN \ifx                   \tex_ifx:D
  \__kernel_primitive:NN \ignorespaces          \tex_ignorespaces:D
  \__kernel_primitive:NN \immediate             \tex_immediate:D
  \__kernel_primitive:NN \indent                \tex_indent:D
  \__kernel_primitive:NN \input                 \tex_input:D
  \__kernel_primitive:NN \inputlineno           \tex_inputlineno:D
  \__kernel_primitive:NN \insert                \tex_insert:D
  \__kernel_primitive:NN \insertpenalties       \tex_insertpenalties:D
  \__kernel_primitive:NN \interlinepenalty      \tex_interlinepenalty:D
  \__kernel_primitive:NN \jobname               \tex_jobname:D
  \__kernel_primitive:NN \kern                  \tex_kern:D
  \__kernel_primitive:NN \language              \tex_language:D
  \__kernel_primitive:NN \lastbox               \tex_lastbox:D
  \__kernel_primitive:NN \lastkern              \tex_lastkern:D
  \__kernel_primitive:NN \lastpenalty           \tex_lastpenalty:D
  \__kernel_primitive:NN \lastskip              \tex_lastskip:D
  \__kernel_primitive:NN \lccode                \tex_lccode:D
  \__kernel_primitive:NN \leaders               \tex_leaders:D
  \__kernel_primitive:NN \left                  \tex_left:D
  \__kernel_primitive:NN \lefthyphenmin         \tex_lefthyphenmin:D
  \__kernel_primitive:NN \leftskip              \tex_leftskip:D
  \__kernel_primitive:NN \leqno                 \tex_leqno:D
  \__kernel_primitive:NN \let                   \tex_let:D
  \__kernel_primitive:NN \limits                \tex_limits:D
  \__kernel_primitive:NN \linepenalty           \tex_linepenalty:D
  \__kernel_primitive:NN \lineskip              \tex_lineskip:D
  \__kernel_primitive:NN \lineskiplimit         \tex_lineskiplimit:D
  \__kernel_primitive:NN \long                  \tex_long:D
  \__kernel_primitive:NN \looseness             \tex_looseness:D
  \__kernel_primitive:NN \lower                 \tex_lower:D
  \__kernel_primitive:NN \lowercase             \tex_lowercase:D
  \__kernel_primitive:NN \mag                   \tex_mag:D
  \__kernel_primitive:NN \mark                  \tex_mark:D
  \__kernel_primitive:NN \mathaccent            \tex_mathaccent:D
  \__kernel_primitive:NN \mathbin               \tex_mathbin:D
  \__kernel_primitive:NN \mathchar              \tex_mathchar:D
  \__kernel_primitive:NN \mathchardef           \tex_mathchardef:D
  \__kernel_primitive:NN \mathchoice            \tex_mathchoice:D
  \__kernel_primitive:NN \mathclose             \tex_mathclose:D
  \__kernel_primitive:NN \mathcode              \tex_mathcode:D
  \__kernel_primitive:NN \mathinner             \tex_mathinner:D
  \__kernel_primitive:NN \mathop                \tex_mathop:D
  \__kernel_primitive:NN \mathopen              \tex_mathopen:D
  \__kernel_primitive:NN \mathord               \tex_mathord:D
  \__kernel_primitive:NN \mathpunct             \tex_mathpunct:D
  \__kernel_primitive:NN \mathrel               \tex_mathrel:D
  \__kernel_primitive:NN \mathsurround          \tex_mathsurround:D
  \__kernel_primitive:NN \maxdeadcycles         \tex_maxdeadcycles:D
  \__kernel_primitive:NN \maxdepth              \tex_maxdepth:D
  \__kernel_primitive:NN \meaning               \tex_meaning:D
  \__kernel_primitive:NN \medmuskip             \tex_medmuskip:D
  \__kernel_primitive:NN \message               \tex_message:D
  \__kernel_primitive:NN \mkern                 \tex_mkern:D
  \__kernel_primitive:NN \month                 \tex_month:D
  \__kernel_primitive:NN \moveleft              \tex_moveleft:D
  \__kernel_primitive:NN \moveright             \tex_moveright:D
  \__kernel_primitive:NN \mskip                 \tex_mskip:D
  \__kernel_primitive:NN \multiply              \tex_multiply:D
  \__kernel_primitive:NN \muskip                \tex_muskip:D
  \__kernel_primitive:NN \muskipdef             \tex_muskipdef:D
  \__kernel_primitive:NN \newlinechar           \tex_newlinechar:D
  \__kernel_primitive:NN \noalign               \tex_noalign:D
  \__kernel_primitive:NN \noboundary            \tex_noboundary:D
  \__kernel_primitive:NN \noexpand              \tex_noexpand:D
  \__kernel_primitive:NN \noindent              \tex_noindent:D
  \__kernel_primitive:NN \nolimits              \tex_nolimits:D
  \__kernel_primitive:NN \nonscript             \tex_nonscript:D
  \__kernel_primitive:NN \nonstopmode           \tex_nonstopmode:D
  \__kernel_primitive:NN \nulldelimiterspace    \tex_nulldelimiterspace:D
  \__kernel_primitive:NN \nullfont              \tex_nullfont:D
  \__kernel_primitive:NN \number                \tex_number:D
  \__kernel_primitive:NN \omit                  \tex_omit:D
  \__kernel_primitive:NN \openin                \tex_openin:D
  \__kernel_primitive:NN \openout               \tex_openout:D
  \__kernel_primitive:NN \or                    \tex_or:D
  \__kernel_primitive:NN \outer                 \tex_outer:D
  \__kernel_primitive:NN \output                \tex_output:D
  \__kernel_primitive:NN \outputpenalty         \tex_outputpenalty:D
  \__kernel_primitive:NN \over                  \tex_over:D
  \__kernel_primitive:NN \overfullrule          \tex_overfullrule:D
  \__kernel_primitive:NN \overline              \tex_overline:D
  \__kernel_primitive:NN \overwithdelims        \tex_overwithdelims:D
  \__kernel_primitive:NN \pagedepth             \tex_pagedepth:D
  \__kernel_primitive:NN \pagefilllstretch      \tex_pagefilllstretch:D
  \__kernel_primitive:NN \pagefillstretch       \tex_pagefillstretch:D
  \__kernel_primitive:NN \pagefilstretch        \tex_pagefilstretch:D
  \__kernel_primitive:NN \pagegoal              \tex_pagegoal:D
  \__kernel_primitive:NN \pageshrink            \tex_pageshrink:D
  \__kernel_primitive:NN \pagestretch           \tex_pagestretch:D
  \__kernel_primitive:NN \pagetotal             \tex_pagetotal:D
  \__kernel_primitive:NN \par                   \tex_par:D
  \__kernel_primitive:NN \parfillskip           \tex_parfillskip:D
  \__kernel_primitive:NN \parindent             \tex_parindent:D
  \__kernel_primitive:NN \parshape              \tex_parshape:D
  \__kernel_primitive:NN \parskip               \tex_parskip:D
  \__kernel_primitive:NN \patterns              \tex_patterns:D
  \__kernel_primitive:NN \pausing               \tex_pausing:D
  \__kernel_primitive:NN \penalty               \tex_penalty:D
  \__kernel_primitive:NN \postdisplaypenalty    \tex_postdisplaypenalty:D
  \__kernel_primitive:NN \predisplaypenalty     \tex_predisplaypenalty:D
  \__kernel_primitive:NN \predisplaysize        \tex_predisplaysize:D
  \__kernel_primitive:NN \pretolerance          \tex_pretolerance:D
  \__kernel_primitive:NN \prevdepth             \tex_prevdepth:D
  \__kernel_primitive:NN \prevgraf              \tex_prevgraf:D
  \__kernel_primitive:NN \radical               \tex_radical:D
  \__kernel_primitive:NN \raise                 \tex_raise:D
  \__kernel_primitive:NN \read                  \tex_read:D
  \__kernel_primitive:NN \relax                 \tex_relax:D
  \__kernel_primitive:NN \relpenalty            \tex_relpenalty:D
  \__kernel_primitive:NN \right                 \tex_right:D
  \__kernel_primitive:NN \righthyphenmin        \tex_righthyphenmin:D
  \__kernel_primitive:NN \rightskip             \tex_rightskip:D
  \__kernel_primitive:NN \romannumeral          \tex_romannumeral:D
  \__kernel_primitive:NN \scriptfont            \tex_scriptfont:D
  \__kernel_primitive:NN \scriptscriptfont      \tex_scriptscriptfont:D
  \__kernel_primitive:NN \scriptscriptstyle     \tex_scriptscriptstyle:D
  \__kernel_primitive:NN \scriptspace           \tex_scriptspace:D
  \__kernel_primitive:NN \scriptstyle           \tex_scriptstyle:D
  \__kernel_primitive:NN \scrollmode            \tex_scrollmode:D
  \__kernel_primitive:NN \setbox                \tex_setbox:D
  \__kernel_primitive:NN \setlanguage           \tex_setlanguage:D
  \__kernel_primitive:NN \sfcode                \tex_sfcode:D
  \__kernel_primitive:NN \shipout               \tex_shipout:D
  \__kernel_primitive:NN \show                  \tex_show:D
  \__kernel_primitive:NN \showbox               \tex_showbox:D
  \__kernel_primitive:NN \showboxbreadth        \tex_showboxbreadth:D
  \__kernel_primitive:NN \showboxdepth          \tex_showboxdepth:D
  \__kernel_primitive:NN \showlists             \tex_showlists:D
  \__kernel_primitive:NN \showthe               \tex_showthe:D
  \__kernel_primitive:NN \skewchar              \tex_skewchar:D
  \__kernel_primitive:NN \skip                  \tex_skip:D
  \__kernel_primitive:NN \skipdef               \tex_skipdef:D
  \__kernel_primitive:NN \spacefactor           \tex_spacefactor:D
  \__kernel_primitive:NN \spaceskip             \tex_spaceskip:D
  \__kernel_primitive:NN \span                  \tex_span:D
  \__kernel_primitive:NN \special               \tex_special:D
  \__kernel_primitive:NN \splitbotmark          \tex_splitbotmark:D
  \__kernel_primitive:NN \splitfirstmark        \tex_splitfirstmark:D
  \__kernel_primitive:NN \splitmaxdepth         \tex_splitmaxdepth:D
  \__kernel_primitive:NN \splittopskip          \tex_splittopskip:D
  \__kernel_primitive:NN \string                \tex_string:D
  \__kernel_primitive:NN \tabskip               \tex_tabskip:D
  \__kernel_primitive:NN \textfont              \tex_textfont:D
  \__kernel_primitive:NN \textstyle             \tex_textstyle:D
  \__kernel_primitive:NN \the                   \tex_the:D
  \__kernel_primitive:NN \thickmuskip           \tex_thickmuskip:D
  \__kernel_primitive:NN \thinmuskip            \tex_thinmuskip:D
  \__kernel_primitive:NN \time                  \tex_time:D
  \__kernel_primitive:NN \toks                  \tex_toks:D
  \__kernel_primitive:NN \toksdef               \tex_toksdef:D
  \__kernel_primitive:NN \tolerance             \tex_tolerance:D
  \__kernel_primitive:NN \topmark               \tex_topmark:D
  \__kernel_primitive:NN \topskip               \tex_topskip:D
  \__kernel_primitive:NN \tracingcommands       \tex_tracingcommands:D
  \__kernel_primitive:NN \tracinglostchars      \tex_tracinglostchars:D
  \__kernel_primitive:NN \tracingmacros         \tex_tracingmacros:D
  \__kernel_primitive:NN \tracingonline         \tex_tracingonline:D
  \__kernel_primitive:NN \tracingoutput         \tex_tracingoutput:D
  \__kernel_primitive:NN \tracingpages          \tex_tracingpages:D
  \__kernel_primitive:NN \tracingparagraphs     \tex_tracingparagraphs:D
  \__kernel_primitive:NN \tracingrestores       \tex_tracingrestores:D
  \__kernel_primitive:NN \tracingstats          \tex_tracingstats:D
  \__kernel_primitive:NN \uccode                \tex_uccode:D
  \__kernel_primitive:NN \uchyph                \tex_uchyph:D
  \__kernel_primitive:NN \underline             \tex_underline:D
  \__kernel_primitive:NN \unhbox                \tex_unhbox:D
  \__kernel_primitive:NN \unhcopy               \tex_unhcopy:D
  \__kernel_primitive:NN \unkern                \tex_unkern:D
  \__kernel_primitive:NN \unpenalty             \tex_unpenalty:D
  \__kernel_primitive:NN \unskip                \tex_unskip:D
  \__kernel_primitive:NN \unvbox                \tex_unvbox:D
  \__kernel_primitive:NN \unvcopy               \tex_unvcopy:D
  \__kernel_primitive:NN \uppercase             \tex_uppercase:D
  \__kernel_primitive:NN \vadjust               \tex_vadjust:D
  \__kernel_primitive:NN \valign                \tex_valign:D
  \__kernel_primitive:NN \vbadness              \tex_vbadness:D
  \__kernel_primitive:NN \vbox                  \tex_vbox:D
  \__kernel_primitive:NN \vcenter               \tex_vcenter:D
  \__kernel_primitive:NN \vfil                  \tex_vfil:D
  \__kernel_primitive:NN \vfill                 \tex_vfill:D
  \__kernel_primitive:NN \vfilneg               \tex_vfilneg:D
  \__kernel_primitive:NN \vfuzz                 \tex_vfuzz:D
  \__kernel_primitive:NN \voffset               \tex_voffset:D
  \__kernel_primitive:NN \vrule                 \tex_vrule:D
  \__kernel_primitive:NN \vsize                 \tex_vsize:D
  \__kernel_primitive:NN \vskip                 \tex_vskip:D
  \__kernel_primitive:NN \vsplit                \tex_vsplit:D
  \__kernel_primitive:NN \vss                   \tex_vss:D
  \__kernel_primitive:NN \vtop                  \tex_vtop:D
  \__kernel_primitive:NN \wd                    \tex_wd:D
  \__kernel_primitive:NN \widowpenalty          \tex_widowpenalty:D
  \__kernel_primitive:NN \write                 \tex_write:D
  \__kernel_primitive:NN \xdef                  \tex_xdef:D
  \__kernel_primitive:NN \xleaders              \tex_xleaders:D
  \__kernel_primitive:NN \xspaceskip            \tex_xspaceskip:D
  \__kernel_primitive:NN \year                  \tex_year:D
  \__kernel_primitive:NN \beginL                \tex_beginL:D
  \__kernel_primitive:NN \beginR                \tex_beginR:D
  \__kernel_primitive:NN \botmarks              \tex_botmarks:D
  \__kernel_primitive:NN \clubpenalties         \tex_clubpenalties:D
  \__kernel_primitive:NN \currentgrouplevel     \tex_currentgrouplevel:D
  \__kernel_primitive:NN \currentgrouptype      \tex_currentgrouptype:D
  \__kernel_primitive:NN \currentifbranch       \tex_currentifbranch:D
  \__kernel_primitive:NN \currentiflevel        \tex_currentiflevel:D
  \__kernel_primitive:NN \currentiftype         \tex_currentiftype:D
  \__kernel_primitive:NN \detokenize            \tex_detokenize:D
  \__kernel_primitive:NN \dimexpr               \tex_dimexpr:D
  \__kernel_primitive:NN \displaywidowpenalties \tex_displaywidowpenalties:D
  \__kernel_primitive:NN \endL                  \tex_endL:D
  \__kernel_primitive:NN \endR                  \tex_endR:D
  \__kernel_primitive:NN \eTeXrevision          \tex_eTeXrevision:D
  \__kernel_primitive:NN \eTeXversion           \tex_eTeXversion:D
  \__kernel_primitive:NN \everyeof              \tex_everyeof:D
  \__kernel_primitive:NN \firstmarks            \tex_firstmarks:D
  \__kernel_primitive:NN \fontchardp            \tex_fontchardp:D
  \__kernel_primitive:NN \fontcharht            \tex_fontcharht:D
  \__kernel_primitive:NN \fontcharic            \tex_fontcharic:D
  \__kernel_primitive:NN \fontcharwd            \tex_fontcharwd:D
  \__kernel_primitive:NN \glueexpr              \tex_glueexpr:D
  \__kernel_primitive:NN \glueshrink            \tex_glueshrink:D
  \__kernel_primitive:NN \glueshrinkorder       \tex_glueshrinkorder:D
  \__kernel_primitive:NN \gluestretch           \tex_gluestretch:D
  \__kernel_primitive:NN \gluestretchorder      \tex_gluestretchorder:D
  \__kernel_primitive:NN \gluetomu              \tex_gluetomu:D
  \__kernel_primitive:NN \ifcsname              \tex_ifcsname:D
  \__kernel_primitive:NN \ifdefined             \tex_ifdefined:D
  \__kernel_primitive:NN \iffontchar            \tex_iffontchar:D
  \__kernel_primitive:NN \interactionmode       \tex_interactionmode:D
  \__kernel_primitive:NN \interlinepenalties    \tex_interlinepenalties:D
  \__kernel_primitive:NN \lastlinefit           \tex_lastlinefit:D
  \__kernel_primitive:NN \lastnodetype          \tex_lastnodetype:D
  \__kernel_primitive:NN \marks                 \tex_marks:D
  \__kernel_primitive:NN \middle                \tex_middle:D
  \__kernel_primitive:NN \muexpr                \tex_muexpr:D
  \__kernel_primitive:NN \mutoglue              \tex_mutoglue:D
  \__kernel_primitive:NN \numexpr               \tex_numexpr:D
  \__kernel_primitive:NN \pagediscards          \tex_pagediscards:D
  \__kernel_primitive:NN \parshapedimen         \tex_parshapedimen:D
  \__kernel_primitive:NN \parshapeindent        \tex_parshapeindent:D
  \__kernel_primitive:NN \parshapelength        \tex_parshapelength:D
  \__kernel_primitive:NN \predisplaydirection   \tex_predisplaydirection:D
  \__kernel_primitive:NN \protected             \tex_protected:D
  \__kernel_primitive:NN \readline              \tex_readline:D
  \__kernel_primitive:NN \savinghyphcodes       \tex_savinghyphcodes:D
  \__kernel_primitive:NN \savingvdiscards       \tex_savingvdiscards:D
  \__kernel_primitive:NN \scantokens            \tex_scantokens:D
  \__kernel_primitive:NN \showgroups            \tex_showgroups:D
  \__kernel_primitive:NN \showifs               \tex_showifs:D
  \__kernel_primitive:NN \showtokens            \tex_showtokens:D
  \__kernel_primitive:NN \splitbotmarks         \tex_splitbotmarks:D
  \__kernel_primitive:NN \splitdiscards         \tex_splitdiscards:D
  \__kernel_primitive:NN \splitfirstmarks       \tex_splitfirstmarks:D
  \__kernel_primitive:NN \TeXXeTstate           \tex_TeXXeTstate:D
  \__kernel_primitive:NN \topmarks              \tex_topmarks:D
  \__kernel_primitive:NN \tracingassigns        \tex_tracingassigns:D
  \__kernel_primitive:NN \tracinggroups         \tex_tracinggroups:D
  \__kernel_primitive:NN \tracingifs            \tex_tracingifs:D
  \__kernel_primitive:NN \tracingnesting        \tex_tracingnesting:D
  \__kernel_primitive:NN \tracingscantokens     \tex_tracingscantokens:D
  \__kernel_primitive:NN \unexpanded            \tex_unexpanded:D
  \__kernel_primitive:NN \unless                \tex_unless:D
  \__kernel_primitive:NN \widowpenalties        \tex_widowpenalties:D
  \__kernel_primitive:NN \pdfannot              \tex_pdfannot:D
  \__kernel_primitive:NN \pdfcatalog            \tex_pdfcatalog:D
  \__kernel_primitive:NN \pdfcompresslevel      \tex_pdfcompresslevel:D
  \__kernel_primitive:NN \pdfcolorstack         \tex_pdfcolorstack:D
  \__kernel_primitive:NN \pdfcolorstackinit     \tex_pdfcolorstackinit:D
  \__kernel_primitive:NN \pdfdecimaldigits      \tex_pdfdecimaldigits:D
  \__kernel_primitive:NN \pdfdest               \tex_pdfdest:D
  \__kernel_primitive:NN \pdfdestmargin         \tex_pdfdestmargin:D
  \__kernel_primitive:NN \pdfendlink            \tex_pdfendlink:D
  \__kernel_primitive:NN \pdfendthread          \tex_pdfendthread:D
  \__kernel_primitive:NN \pdffakespace          \tex_pdffakespace:D
  \__kernel_primitive:NN \pdffontattr           \tex_pdffontattr:D
  \__kernel_primitive:NN \pdffontname           \tex_pdffontname:D
  \__kernel_primitive:NN \pdffontobjnum         \tex_pdffontobjnum:D
  \__kernel_primitive:NN \pdfgamma              \tex_pdfgamma:D
  \__kernel_primitive:NN \pdfgentounicode       \tex_pdfgentounicode:D
  \__kernel_primitive:NN \pdfglyphtounicode     \tex_pdfglyphtounicode:D
  \__kernel_primitive:NN \pdfhorigin            \tex_pdfhorigin:D
  \__kernel_primitive:NN \pdfimageapplygamma    \tex_pdfimageapplygamma:D
  \__kernel_primitive:NN \pdfimagegamma         \tex_pdfimagegamma:D
  \__kernel_primitive:NN \pdfimagehicolor       \tex_pdfimagehicolor:D
  \__kernel_primitive:NN \pdfimageresolution    \tex_pdfimageresolution:D
  \__kernel_primitive:NN \pdfincludechars       \tex_pdfincludechars:D
  \__kernel_primitive:NN \pdfinclusioncopyfonts \tex_pdfinclusioncopyfonts:D
  \__kernel_primitive:NN \pdfinclusionerrorlevel
    \tex_pdfinclusionerrorlevel:D
  \__kernel_primitive:NN \pdfinfo               \tex_pdfinfo:D
  \__kernel_primitive:NN \pdfinfoomitdate       \tex_pdfinfoomitdate:D
  \__kernel_primitive:NN \pdfinterwordspaceoff  \tex_pdfinterwordspaceoff:D
  \__kernel_primitive:NN \pdfinterwordspaceon   \tex_pdfinterwordspaceon:D
  \__kernel_primitive:NN \pdflastannot          \tex_pdflastannot:D
  \__kernel_primitive:NN \pdflastlink           \tex_pdflastlink:D
  \__kernel_primitive:NN \pdflastobj            \tex_pdflastobj:D
  \__kernel_primitive:NN \pdflastxform          \tex_pdflastxform:D
  \__kernel_primitive:NN \pdflastximage         \tex_pdflastximage:D
  \__kernel_primitive:NN \pdflastximagecolordepth
    \tex_pdflastximagecolordepth:D
  \__kernel_primitive:NN \pdflastximagepages    \tex_pdflastximagepages:D
  \__kernel_primitive:NN \pdflinkmargin         \tex_pdflinkmargin:D
  \__kernel_primitive:NN \pdfliteral            \tex_pdfliteral:D
  \__kernel_primitive:NN \pdfmapfile            \tex_pdfmapfile:D
  \__kernel_primitive:NN \pdfmapline            \tex_pdfmapline:D
  \__kernel_primitive:NN \pdfmajorversion       \tex_pdfmajorversion:D
  \__kernel_primitive:NN \pdfminorversion       \tex_pdfminorversion:D
  \__kernel_primitive:NN \pdfnames              \tex_pdfnames:D
  \__kernel_primitive:NN \pdfnobuiltintounicode \tex_pdfnobuiltintounicode:D
  \__kernel_primitive:NN \pdfobj                \tex_pdfobj:D
  \__kernel_primitive:NN \pdfobjcompresslevel   \tex_pdfobjcompresslevel:D
  \__kernel_primitive:NN \pdfomitcharset        \tex_pdfomitcharset:D
  \__kernel_primitive:NN \pdfoutline            \tex_pdfoutline:D
  \__kernel_primitive:NN \pdfoutput             \tex_pdfoutput:D
  \__kernel_primitive:NN \pdfpageattr           \tex_pdfpageattr:D
  \__kernel_primitive:NN \pdfpagebox            \tex_pdfpagebox:D
  \__kernel_primitive:NN \pdfpageref            \tex_pdfpageref:D
  \__kernel_primitive:NN \pdfpageresources      \tex_pdfpageresources:D
  \__kernel_primitive:NN \pdfpagesattr          \tex_pdfpagesattr:D
  \__kernel_primitive:NN \pdfptexuseunderscore  \tex_pdfptexuseunderscore:D
  \__kernel_primitive:NN \pdfrefobj             \tex_pdfrefobj:D
  \__kernel_primitive:NN \pdfrefxform           \tex_pdfrefxform:D
  \__kernel_primitive:NN \pdfrefximage          \tex_pdfrefximage:D
  \__kernel_primitive:NN \pdfrestore            \tex_pdfrestore:D
  \__kernel_primitive:NN \pdfretval             \tex_pdfretval:D
  \__kernel_primitive:NN \pdfrunninglinkoff     \tex_pdfrunninglinkoff:D
  \__kernel_primitive:NN \pdfrunninglinkon      \tex_pdfrunninglinkon:D
  \__kernel_primitive:NN \pdfsave               \tex_pdfsave:D
  \__kernel_primitive:NN \pdfsetmatrix          \tex_pdfsetmatrix:D
  \__kernel_primitive:NN \pdfstartlink          \tex_pdfstartlink:D
  \__kernel_primitive:NN \pdfstartthread        \tex_pdfstartthread:D
  \__kernel_primitive:NN \pdfsuppressptexinfo   \tex_pdfsuppressptexinfo:D
  \__kernel_primitive:NN \pdfsuppresswarningdupdest
    \tex_pdfsuppresswarningdupdest:D
  \__kernel_primitive:NN \pdfsuppresswarningdupmap
    \tex_pdfsuppresswarningdupmap:D
  \__kernel_primitive:NN \pdfsuppresswarningpagegroup
    \tex_pdfsuppresswarningpagegroup:D
  \__kernel_primitive:NN \pdfthread             \tex_pdfthread:D
  \__kernel_primitive:NN \pdfthreadmargin       \tex_pdfthreadmargin:D
  \__kernel_primitive:NN \pdftrailer            \tex_pdftrailer:D
  \__kernel_primitive:NN \pdftrailerid          \tex_pdftrailerid:D
  \__kernel_primitive:NN \pdfuniqueresname      \tex_pdfuniqueresname:D
  \__kernel_primitive:NN \pdfvorigin            \tex_pdfvorigin:D
  \__kernel_primitive:NN \pdfxform              \tex_pdfxform:D
  \__kernel_primitive:NN \pdfxformname          \tex_pdfxformname:D
  \__kernel_primitive:NN \pdfximage             \tex_pdfximage:D
  \__kernel_primitive:NN \pdfximagebbox         \tex_pdfximagebbox:D
  \__kernel_primitive:NN \ifpdfabsdim           \tex_ifabsdim:D
  \__kernel_primitive:NN \ifpdfabsnum           \tex_ifabsnum:D
  \__kernel_primitive:NN \ifpdfprimitive        \tex_ifprimitive:D
  \__kernel_primitive:NN \pdfadjustinterwordglue
    \tex_adjustinterwordglue:D
  \__kernel_primitive:NN \pdfadjustspacing      \tex_adjustspacing:D
  \__kernel_primitive:NN \pdfappendkern         \tex_appendkern:D
  \__kernel_primitive:NN \pdfcopyfont           \tex_copyfont:D
  \__kernel_primitive:NN \pdfcreationdate       \tex_creationdate:D
  \__kernel_primitive:NN \pdfdraftmode          \tex_draftmode:D
  \__kernel_primitive:NN \pdfeachlinedepth      \tex_eachlinedepth:D
  \__kernel_primitive:NN \pdfeachlineheight     \tex_eachlineheight:D
  \__kernel_primitive:NN \pdfelapsedtime        \tex_elapsedtime:D
  \__kernel_primitive:NN \pdfescapehex          \tex_escapehex:D
  \__kernel_primitive:NN \pdfescapename         \tex_escapename:D
  \__kernel_primitive:NN \pdfescapestring       \tex_escapestring:D
  \__kernel_primitive:NN \pdffirstlineheight    \tex_firstlineheight:D
  \__kernel_primitive:NN \pdffontexpand         \tex_fontexpand:D
  \__kernel_primitive:NN \pdffontsize           \tex_fontsize:D
  \__kernel_primitive:NN \pdfignoreddimen       \tex_ignoreddimen:D
  \__kernel_primitive:NN \pdfinsertht           \tex_insertht:D
  \__kernel_primitive:NN \pdflastlinedepth      \tex_lastlinedepth:D
  \__kernel_primitive:NN \pdflastmatch          \tex_lastmatch:D
  \__kernel_primitive:NN \pdflastxpos           \tex_lastxpos:D
  \__kernel_primitive:NN \pdflastypos           \tex_lastypos:D
  \__kernel_primitive:NN \pdfmatch              \tex_match:D
  \__kernel_primitive:NN \pdfnoligatures        \tex_noligatures:D
  \__kernel_primitive:NN \pdfnormaldeviate      \tex_normaldeviate:D
  \__kernel_primitive:NN \pdfpageheight         \tex_pageheight:D
  \__kernel_primitive:NN \pdfpagewidth          \tex_pagewidth:D
  \__kernel_primitive:NN \pdfpkmode             \tex_pkmode:D
  \__kernel_primitive:NN \pdfpkresolution       \tex_pkresolution:D
  \__kernel_primitive:NN \pdfprimitive          \tex_primitive:D
  \__kernel_primitive:NN \pdfprependkern        \tex_prependkern:D
  \__kernel_primitive:NN \pdfprotrudechars      \tex_protrudechars:D
  \__kernel_primitive:NN \pdfpxdimen            \tex_pxdimen:D
  \__kernel_primitive:NN \pdfrandomseed         \tex_randomseed:D
  \__kernel_primitive:NN \pdfresettimer         \tex_resettimer:D
  \__kernel_primitive:NN \pdfsavepos            \tex_savepos:D
  \__kernel_primitive:NN \pdfsetrandomseed      \tex_setrandomseed:D
  \__kernel_primitive:NN \pdfshellescape        \tex_shellescape:D
  \__kernel_primitive:NN \pdftracingfonts       \tex_tracingfonts:D
  \__kernel_primitive:NN \pdfunescapehex        \tex_unescapehex:D
  \__kernel_primitive:NN \pdfuniformdeviate     \tex_uniformdeviate:D
  \__kernel_primitive:NN \pdftexbanner          \tex_pdftexbanner:D
  \__kernel_primitive:NN \pdftexrevision        \tex_pdftexrevision:D
  \__kernel_primitive:NN \pdftexversion         \tex_pdftexversion:D
  \__kernel_primitive:NN \efcode                \tex_efcode:D
  \__kernel_primitive:NN \ifincsname            \tex_ifincsname:D
  \__kernel_primitive:NN \knaccode              \tex_knaccode:D
  \__kernel_primitive:NN \knbccode              \tex_knbccode:D
  \__kernel_primitive:NN \knbscode              \tex_knbscode:D
  \__kernel_primitive:NN \leftmarginkern        \tex_leftmarginkern:D
  \__kernel_primitive:NN \letterspacefont       \tex_letterspacefont:D
  \__kernel_primitive:NN \lpcode                \tex_lpcode:D
  \__kernel_primitive:NN \quitvmode             \tex_quitvmode:D
  \__kernel_primitive:NN \rightmarginkern       \tex_rightmarginkern:D
  \__kernel_primitive:NN \rpcode                \tex_rpcode:D
  \__kernel_primitive:NN \shbscode              \tex_shbscode:D
  \__kernel_primitive:NN \stbscode              \tex_stbscode:D
  \__kernel_primitive:NN \synctex               \tex_synctex:D
  \__kernel_primitive:NN \tagcode               \tex_tagcode:D
  \__kernel_primitive:NN \pdfstrcmp             \tex_strcmp:D
  \__kernel_primitive:NN \pdffilesize           \tex_filesize:D
  \__kernel_primitive:NN \pdfmdfivesum          \tex_mdfivesum:D
  \__kernel_primitive:NN \pdffilemoddate        \tex_filemoddate:D
  \__kernel_primitive:NN \pdffiledump           \tex_filedump:D
  \__kernel_primitive:NN \suppressfontnotfounderror
    \tex_suppressfontnotfounderror:D
  \__kernel_primitive:NN \XeTeXcharclass        \tex_XeTeXcharclass:D
  \__kernel_primitive:NN \XeTeXcharglyph        \tex_XeTeXcharglyph:D
  \__kernel_primitive:NN \XeTeXcountfeatures    \tex_XeTeXcountfeatures:D
  \__kernel_primitive:NN \XeTeXcountglyphs      \tex_XeTeXcountglyphs:D
  \__kernel_primitive:NN \XeTeXcountselectors   \tex_XeTeXcountselectors:D
  \__kernel_primitive:NN \XeTeXcountvariations  \tex_XeTeXcountvariations:D
  \__kernel_primitive:NN \XeTeXdefaultencoding  \tex_XeTeXdefaultencoding:D
  \__kernel_primitive:NN \XeTeXdashbreakstate   \tex_XeTeXdashbreakstate:D
  \__kernel_primitive:NN \XeTeXfeaturecode      \tex_XeTeXfeaturecode:D
  \__kernel_primitive:NN \XeTeXfeaturename      \tex_XeTeXfeaturename:D
  \__kernel_primitive:NN \XeTeXfindfeaturebyname
    \tex_XeTeXfindfeaturebyname:D
  \__kernel_primitive:NN \XeTeXfindselectorbyname
    \tex_XeTeXfindselectorbyname:D
  \__kernel_primitive:NN \XeTeXfindvariationbyname
    \tex_XeTeXfindvariationbyname:D
  \__kernel_primitive:NN \XeTeXfirstfontchar    \tex_XeTeXfirstfontchar:D
  \__kernel_primitive:NN \XeTeXfonttype         \tex_XeTeXfonttype:D
  \__kernel_primitive:NN \XeTeXgenerateactualtext
    \tex_XeTeXgenerateactualtext:D
  \__kernel_primitive:NN \XeTeXglyph            \tex_XeTeXglyph:D
  \__kernel_primitive:NN \XeTeXglyphbounds      \tex_XeTeXglyphbounds:D
  \__kernel_primitive:NN \XeTeXglyphindex       \tex_XeTeXglyphindex:D
  \__kernel_primitive:NN \XeTeXglyphname        \tex_XeTeXglyphname:D
  \__kernel_primitive:NN \XeTeXinputencoding    \tex_XeTeXinputencoding:D
  \__kernel_primitive:NN \XeTeXinputnormalization
    \tex_XeTeXinputnormalization:D
  \__kernel_primitive:NN \XeTeXinterchartokenstate
    \tex_XeTeXinterchartokenstate:D
  \__kernel_primitive:NN \XeTeXinterchartoks    \tex_XeTeXinterchartoks:D
  \__kernel_primitive:NN \XeTeXisdefaultselector
    \tex_XeTeXisdefaultselector:D
  \__kernel_primitive:NN \XeTeXisexclusivefeature
    \tex_XeTeXisexclusivefeature:D
  \__kernel_primitive:NN \XeTeXlastfontchar     \tex_XeTeXlastfontchar:D
  \__kernel_primitive:NN \XeTeXlinebreakskip    \tex_XeTeXlinebreakskip:D
  \__kernel_primitive:NN \XeTeXlinebreaklocale  \tex_XeTeXlinebreaklocale:D
  \__kernel_primitive:NN \XeTeXlinebreakpenalty \tex_XeTeXlinebreakpenalty:D
  \__kernel_primitive:NN \XeTeXOTcountfeatures  \tex_XeTeXOTcountfeatures:D
  \__kernel_primitive:NN \XeTeXOTcountlanguages \tex_XeTeXOTcountlanguages:D
  \__kernel_primitive:NN \XeTeXOTcountscripts   \tex_XeTeXOTcountscripts:D
  \__kernel_primitive:NN \XeTeXOTfeaturetag     \tex_XeTeXOTfeaturetag:D
  \__kernel_primitive:NN \XeTeXOTlanguagetag    \tex_XeTeXOTlanguagetag:D
  \__kernel_primitive:NN \XeTeXOTscripttag      \tex_XeTeXOTscripttag:D
  \__kernel_primitive:NN \XeTeXpdffile          \tex_XeTeXpdffile:D
  \__kernel_primitive:NN \XeTeXpdfpagecount     \tex_XeTeXpdfpagecount:D
  \__kernel_primitive:NN \XeTeXpicfile          \tex_XeTeXpicfile:D
  \__kernel_primitive:NN \XeTeXrevision         \tex_XeTeXrevision:D
  \__kernel_primitive:NN \XeTeXselectorname     \tex_XeTeXselectorname:D
  \__kernel_primitive:NN \XeTeXtracingfonts     \tex_XeTeXtracingfonts:D
  \__kernel_primitive:NN \XeTeXupwardsmode      \tex_XeTeXupwardsmode:D
  \__kernel_primitive:NN \XeTeXuseglyphmetrics  \tex_XeTeXuseglyphmetrics:D
  \__kernel_primitive:NN \XeTeXvariation        \tex_XeTeXvariation:D
  \__kernel_primitive:NN \XeTeXvariationdefault \tex_XeTeXvariationdefault:D
  \__kernel_primitive:NN \XeTeXvariationmax     \tex_XeTeXvariationmax:D
  \__kernel_primitive:NN \XeTeXvariationmin     \tex_XeTeXvariationmin:D
  \__kernel_primitive:NN \XeTeXvariationname    \tex_XeTeXvariationname:D
  \__kernel_primitive:NN \XeTeXversion          \tex_XeTeXversion:D
  \__kernel_primitive:NN \XeTeXselectorcode     \tex_XeTeXselectorcode:D
  \__kernel_primitive:NN \XeTeXinterwordspaceshaping
                   \tex_XeTeXinterwordspaceshaping:D
  \__kernel_primitive:NN \XeTeXhyphenatablelength
                   \tex_XeTeXhyphenatablelength:D
  \__kernel_primitive:NN \creationdate          \tex_creationdate:D
  \__kernel_primitive:NN \elapsedtime           \tex_elapsedtime:D
  \__kernel_primitive:NN \filedump              \tex_filedump:D
  \__kernel_primitive:NN \filemoddate           \tex_filemoddate:D
  \__kernel_primitive:NN \filesize              \tex_filesize:D
  \__kernel_primitive:NN \mdfivesum             \tex_mdfivesum:D
  \__kernel_primitive:NN \ifprimitive           \tex_ifprimitive:D
  \__kernel_primitive:NN \primitive             \tex_primitive:D
  \__kernel_primitive:NN \resettimer            \tex_resettimer:D
  \__kernel_primitive:NN \shellescape           \tex_shellescape:D
  \__kernel_primitive:NN \XeTeXprotrudechars    \tex_protrudechars:D
  \__kernel_primitive:NN \alignmark             \tex_alignmark:D
  \__kernel_primitive:NN \aligntab              \tex_aligntab:D
  \__kernel_primitive:NN \attribute             \tex_attribute:D
  \__kernel_primitive:NN \attributedef          \tex_attributedef:D
  \__kernel_primitive:NN \automaticdiscretionary
    \tex_automaticdiscretionary:D
  \__kernel_primitive:NN \automatichyphenmode   \tex_automatichyphenmode:D
  \__kernel_primitive:NN \automatichyphenpenalty
    \tex_automatichyphenpenalty:D
  \__kernel_primitive:NN \begincsname           \tex_begincsname:D
  \__kernel_primitive:NN \bodydir               \tex_bodydir:D
  \__kernel_primitive:NN \bodydirection         \tex_bodydirection:D
  \__kernel_primitive:NN \boundary              \tex_boundary:D
  \__kernel_primitive:NN \boxdir                \tex_boxdir:D
  \__kernel_primitive:NN \boxdirection          \tex_boxdirection:D
  \__kernel_primitive:NN \breakafterdirmode     \tex_breakafterdirmode:D
  \__kernel_primitive:NN \catcodetable          \tex_catcodetable:D
  \__kernel_primitive:NN \clearmarks            \tex_clearmarks:D
  \__kernel_primitive:NN \crampeddisplaystyle   \tex_crampeddisplaystyle:D
  \__kernel_primitive:NN \crampedscriptscriptstyle
    \tex_crampedscriptscriptstyle:D
  \__kernel_primitive:NN \crampedscriptstyle    \tex_crampedscriptstyle:D
  \__kernel_primitive:NN \crampedtextstyle      \tex_crampedtextstyle:D
  \__kernel_primitive:NN \csstring              \tex_csstring:D
  \__kernel_primitive:NN \deferred              \tex_deferred:D
  \__kernel_primitive:NN \discretionaryligaturemode
    \tex_discretionaryligaturemode:D
  \__kernel_primitive:NN \directlua             \tex_directlua:D
  \__kernel_primitive:NN \dviextension          \tex_dviextension:D
  \__kernel_primitive:NN \dvifeedback           \tex_dvifeedback:D
  \__kernel_primitive:NN \dvivariable           \tex_dvivariable:D
  \__kernel_primitive:NN \eTeXglueshrinkorder   \tex_eTeXglueshrinkorder:D
  \__kernel_primitive:NN \eTeXgluestretchorder  \tex_eTeXgluestretchorder:D
  \__kernel_primitive:NN \endlocalcontrol       \tex_endlocalcontrol:D
  \__kernel_primitive:NN \etoksapp              \tex_etoksapp:D
  \__kernel_primitive:NN \etokspre              \tex_etokspre:D
  \__kernel_primitive:NN \exceptionpenalty      \tex_exceptionpenalty:D
  \__kernel_primitive:NN \exhyphenchar          \tex_exhyphenchar:D
  \__kernel_primitive:NN \explicithyphenpenalty \tex_explicithyphenpenalty:D
  \__kernel_primitive:NN \expanded              \tex_expanded:D
  \__kernel_primitive:NN \explicitdiscretionary \tex_explicitdiscretionary:D
  \__kernel_primitive:NN \firstvalidlanguage    \tex_firstvalidlanguage:D
  \__kernel_primitive:NN \fontid                \tex_fontid:D
  \__kernel_primitive:NN \formatname            \tex_formatname:D
  \__kernel_primitive:NN \hjcode                \tex_hjcode:D
  \__kernel_primitive:NN \hpack                 \tex_hpack:D
  \__kernel_primitive:NN \hyphenationbounds     \tex_hyphenationbounds:D
  \__kernel_primitive:NN \hyphenationmin        \tex_hyphenationmin:D
  \__kernel_primitive:NN \hyphenpenaltymode     \tex_hyphenpenaltymode:D
  \__kernel_primitive:NN \gleaders              \tex_gleaders:D
  \__kernel_primitive:NN \glet                  \tex_glet:D
  \__kernel_primitive:NN \glyphdimensionsmode   \tex_glyphdimensionsmode:D
  \__kernel_primitive:NN \gtoksapp              \tex_gtoksapp:D
  \__kernel_primitive:NN \gtokspre              \tex_gtokspre:D
  \__kernel_primitive:NN \ifcondition           \tex_ifcondition:D
  \__kernel_primitive:NN \immediateassigned     \tex_immediateassigned:D
  \__kernel_primitive:NN \immediateassignment   \tex_immediateassignment:D
  \__kernel_primitive:NN \initcatcodetable      \tex_initcatcodetable:D
  \__kernel_primitive:NN \lastnamedcs           \tex_lastnamedcs:D
  \__kernel_primitive:NN \latelua               \tex_latelua:D
  \__kernel_primitive:NN \lateluafunction       \tex_lateluafunction:D
  \__kernel_primitive:NN \leftghost             \tex_leftghost:D
  \__kernel_primitive:NN \letcharcode           \tex_letcharcode:D
  \__kernel_primitive:NN \linedir               \tex_linedir:D
  \__kernel_primitive:NN \linedirection         \tex_linedirection:D
  \__kernel_primitive:NN \localbrokenpenalty    \tex_localbrokenpenalty:D
  \__kernel_primitive:NN \localinterlinepenalty \tex_localinterlinepenalty:D
  \__kernel_primitive:NN \luabytecode           \tex_luabytecode:D
  \__kernel_primitive:NN \luabytecodecall       \tex_luabytecodecall:D
  \__kernel_primitive:NN \luacopyinputnodes     \tex_luacopyinputnodes:D
  \__kernel_primitive:NN \luadef                \tex_luadef:D
  \__kernel_primitive:NN \localleftbox          \tex_localleftbox:D
  \__kernel_primitive:NN \localrightbox         \tex_localrightbox:D
  \__kernel_primitive:NN \luaescapestring       \tex_luaescapestring:D
  \__kernel_primitive:NN \luafunction           \tex_luafunction:D
  \__kernel_primitive:NN \luafunctioncall       \tex_luafunctioncall:D
  \__kernel_primitive:NN \luatexbanner          \tex_luatexbanner:D
  \__kernel_primitive:NN \luatexrevision        \tex_luatexrevision:D
  \__kernel_primitive:NN \luatexversion         \tex_luatexversion:D
  \__kernel_primitive:NN \mathdefaultsmode      \tex_mathdefaultsmode:D
  \__kernel_primitive:NN \mathdelimitersmode    \tex_mathdelimitersmode:D
  \__kernel_primitive:NN \mathdir               \tex_mathdir:D
  \__kernel_primitive:NN \mathdirection         \tex_mathdirection:D
  \__kernel_primitive:NN \mathdisplayskipmode   \tex_mathdisplayskipmode:D
  \__kernel_primitive:NN \matheqdirmode         \tex_matheqdirmode:D
  \__kernel_primitive:NN \matheqnogapstep       \tex_matheqnogapstep:D
  \__kernel_primitive:NN \mathemptydisplaymode  \tex_mathemptydisplaymode:D
  \__kernel_primitive:NN \mathflattenmode       \tex_mathflattenmode:D
  \__kernel_primitive:NN \mathitalicsmode       \tex_mathitalicsmode:D
  \__kernel_primitive:NN \mathnolimitsmode      \tex_mathnolimitsmode:D
  \__kernel_primitive:NN \mathoption            \tex_mathoption:D
  \__kernel_primitive:NN \mathpenaltiesmode     \tex_mathpenaltiesmode:D
  \__kernel_primitive:NN \mathrulesfam          \tex_mathrulesfam:D
  \__kernel_primitive:NN \mathscriptsmode       \tex_mathscriptsmode:D
  \__kernel_primitive:NN \mathscriptboxmode     \tex_mathscriptboxmode:D
  \__kernel_primitive:NN \mathscriptcharmode    \tex_mathscriptcharmode:D
  \__kernel_primitive:NN \mathstyle             \tex_mathstyle:D
  \__kernel_primitive:NN \mathsurroundmode      \tex_mathsurroundmode:D
  \__kernel_primitive:NN \mathsurroundskip      \tex_mathsurroundskip:D
  \__kernel_primitive:NN \nohrule               \tex_nohrule:D
  \__kernel_primitive:NN \nokerns               \tex_nokerns:D
  \__kernel_primitive:NN \noligs                \tex_noligs:D
  \__kernel_primitive:NN \nospaces              \tex_nospaces:D
  \__kernel_primitive:NN \novrule               \tex_novrule:D
  \__kernel_primitive:NN \outputbox             \tex_outputbox:D
  \__kernel_primitive:NN \pagebottomoffset      \tex_pagebottomoffset:D
  \__kernel_primitive:NN \pagedir               \tex_pagedir:D
  \__kernel_primitive:NN \pagedirection         \tex_pagedirection:D
  \__kernel_primitive:NN \pageleftoffset        \tex_pageleftoffset:D
  \__kernel_primitive:NN \pagerightoffset       \tex_pagerightoffset:D
  \__kernel_primitive:NN \pagetopoffset         \tex_pagetopoffset:D
  \__kernel_primitive:NN \pardir                \tex_pardir:D
  \__kernel_primitive:NN \pardirection          \tex_pardirection:D
  \__kernel_primitive:NN \pdfextension          \tex_pdfextension:D
  \__kernel_primitive:NN \pdffeedback           \tex_pdffeedback:D
  \__kernel_primitive:NN \pdfvariable           \tex_pdfvariable:D
  \__kernel_primitive:NN \postexhyphenchar      \tex_postexhyphenchar:D
  \__kernel_primitive:NN \posthyphenchar        \tex_posthyphenchar:D
  \__kernel_primitive:NN \prebinoppenalty       \tex_prebinoppenalty:D
  \__kernel_primitive:NN \predisplaygapfactor   \tex_predisplaygapfactor:D
  \__kernel_primitive:NN \preexhyphenchar       \tex_preexhyphenchar:D
  \__kernel_primitive:NN \prehyphenchar         \tex_prehyphenchar:D
  \__kernel_primitive:NN \prerelpenalty         \tex_prerelpenalty:D
  \__kernel_primitive:NN \protrusionboundary    \tex_protrusionboundary:D
  \__kernel_primitive:NN \rightghost            \tex_rightghost:D
  \__kernel_primitive:NN \savecatcodetable      \tex_savecatcodetable:D
  \__kernel_primitive:NN \scantextokens         \tex_scantextokens:D
  \__kernel_primitive:NN \setfontid             \tex_setfontid:D
  \__kernel_primitive:NN \shapemode             \tex_shapemode:D
  \__kernel_primitive:NN \suppressifcsnameerror \tex_suppressifcsnameerror:D
  \__kernel_primitive:NN \suppresslongerror     \tex_suppresslongerror:D
  \__kernel_primitive:NN \suppressmathparerror  \tex_suppressmathparerror:D
  \__kernel_primitive:NN \suppressoutererror    \tex_suppressoutererror:D
  \__kernel_primitive:NN \suppressprimitiveerror
    \tex_suppressprimitiveerror:D
  \__kernel_primitive:NN \textdir               \tex_textdir:D
  \__kernel_primitive:NN \textdirection         \tex_textdirection:D
  \__kernel_primitive:NN \toksapp               \tex_toksapp:D
  \__kernel_primitive:NN \tokspre               \tex_tokspre:D
  \__kernel_primitive:NN \tpack                 \tex_tpack:D
  \__kernel_primitive:NN \variablefam           \tex_variablefam:D
  \__kernel_primitive:NN \vpack                 \tex_vpack:D
  \__kernel_primitive:NN \wordboundary          \tex_wordboundary:D
  \__kernel_primitive:NN \xtoksapp              \tex_xtoksapp:D
  \__kernel_primitive:NN \xtokspre              \tex_xtokspre:D
  \__kernel_primitive:NN \adjustspacing         \tex_adjustspacing:D
  \__kernel_primitive:NN \copyfont              \tex_copyfont:D
  \__kernel_primitive:NN \draftmode             \tex_draftmode:D
  \__kernel_primitive:NN \expandglyphsinfont    \tex_fontexpand:D
  \__kernel_primitive:NN \ifabsdim              \tex_ifabsdim:D
  \__kernel_primitive:NN \ifabsnum              \tex_ifabsnum:D
  \__kernel_primitive:NN \ignoreligaturesinfont \tex_ignoreligaturesinfont:D
  \__kernel_primitive:NN \insertht              \tex_insertht:D
  \__kernel_primitive:NN \lastsavedboxresourceindex
    \tex_pdflastxform:D
  \__kernel_primitive:NN \lastsavedimageresourceindex
    \tex_pdflastximage:D
  \__kernel_primitive:NN \lastsavedimageresourcepages
    \tex_pdflastximagepages:D
  \__kernel_primitive:NN \lastxpos              \tex_lastxpos:D
  \__kernel_primitive:NN \lastypos              \tex_lastypos:D
  \__kernel_primitive:NN \normaldeviate         \tex_normaldeviate:D
  \__kernel_primitive:NN \outputmode            \tex_pdfoutput:D
  \__kernel_primitive:NN \pageheight            \tex_pageheight:D
  \__kernel_primitive:NN \pagewidth             \tex_pagewidth:D
  \__kernel_primitive:NN \protrudechars         \tex_protrudechars:D
  \__kernel_primitive:NN \pxdimen               \tex_pxdimen:D
  \__kernel_primitive:NN \randomseed            \tex_randomseed:D
  \__kernel_primitive:NN \useboxresource        \tex_pdfrefxform:D
  \__kernel_primitive:NN \useimageresource      \tex_pdfrefximage:D
  \__kernel_primitive:NN \savepos               \tex_savepos:D
  \__kernel_primitive:NN \saveboxresource       \tex_pdfxform:D
  \__kernel_primitive:NN \saveimageresource     \tex_pdfximage:D
  \__kernel_primitive:NN \setrandomseed         \tex_setrandomseed:D
  \__kernel_primitive:NN \tracingfonts          \tex_tracingfonts:D
  \__kernel_primitive:NN \uniformdeviate        \tex_uniformdeviate:D
  \__kernel_primitive:NN \Uchar                 \tex_Uchar:D
  \__kernel_primitive:NN \Ucharcat              \tex_Ucharcat:D
  \__kernel_primitive:NN \Udelcode              \tex_Udelcode:D
  \__kernel_primitive:NN \Udelcodenum           \tex_Udelcodenum:D
  \__kernel_primitive:NN \Udelimiter            \tex_Udelimiter:D
  \__kernel_primitive:NN \Udelimiterover        \tex_Udelimiterover:D
  \__kernel_primitive:NN \Udelimiterunder       \tex_Udelimiterunder:D
  \__kernel_primitive:NN \Uhextensible          \tex_Uhextensible:D
  \__kernel_primitive:NN \Uleft                 \tex_Uleft:D
  \__kernel_primitive:NN \Umathaccent           \tex_Umathaccent:D
  \__kernel_primitive:NN \Umathaxis             \tex_Umathaxis:D
  \__kernel_primitive:NN \Umathbinbinspacing    \tex_Umathbinbinspacing:D
  \__kernel_primitive:NN \Umathbinclosespacing  \tex_Umathbinclosespacing:D
  \__kernel_primitive:NN \Umathbininnerspacing  \tex_Umathbininnerspacing:D
  \__kernel_primitive:NN \Umathbinopenspacing   \tex_Umathbinopenspacing:D
  \__kernel_primitive:NN \Umathbinopspacing     \tex_Umathbinopspacing:D
  \__kernel_primitive:NN \Umathbinordspacing    \tex_Umathbinordspacing:D
  \__kernel_primitive:NN \Umathbinpunctspacing  \tex_Umathbinpunctspacing:D
  \__kernel_primitive:NN \Umathbinrelspacing    \tex_Umathbinrelspacing:D
  \__kernel_primitive:NN \Umathchar             \tex_Umathchar:D
  \__kernel_primitive:NN \Umathcharclass        \tex_Umathcharclass:D
  \__kernel_primitive:NN \Umathchardef          \tex_Umathchardef:D
  \__kernel_primitive:NN \Umathcharfam          \tex_Umathcharfam:D
  \__kernel_primitive:NN \Umathcharnum          \tex_Umathcharnum:D
  \__kernel_primitive:NN \Umathcharnumdef       \tex_Umathcharnumdef:D
  \__kernel_primitive:NN \Umathcharslot         \tex_Umathcharslot:D
  \__kernel_primitive:NN \Umathclosebinspacing  \tex_Umathclosebinspacing:D
  \__kernel_primitive:NN \Umathcloseclosespacing
    \tex_Umathcloseclosespacing:D
  \__kernel_primitive:NN \Umathcloseinnerspacing
    \tex_Umathcloseinnerspacing:D
  \__kernel_primitive:NN \Umathcloseopenspacing \tex_Umathcloseopenspacing:D
  \__kernel_primitive:NN \Umathcloseopspacing   \tex_Umathcloseopspacing:D
  \__kernel_primitive:NN \Umathcloseordspacing  \tex_Umathcloseordspacing:D
  \__kernel_primitive:NN \Umathclosepunctspacing
    \tex_Umathclosepunctspacing:D
  \__kernel_primitive:NN \Umathcloserelspacing  \tex_Umathcloserelspacing:D
  \__kernel_primitive:NN \Umathcode             \tex_Umathcode:D
  \__kernel_primitive:NN \Umathcodenum          \tex_Umathcodenum:D
  \__kernel_primitive:NN \Umathconnectoroverlapmin
    \tex_Umathconnectoroverlapmin:D
  \__kernel_primitive:NN \Umathfractiondelsize  \tex_Umathfractiondelsize:D
  \__kernel_primitive:NN \Umathfractiondenomdown
    \tex_Umathfractiondenomdown:D
  \__kernel_primitive:NN \Umathfractiondenomvgap
    \tex_Umathfractiondenomvgap:D
  \__kernel_primitive:NN \Umathfractionnumup    \tex_Umathfractionnumup:D
  \__kernel_primitive:NN \Umathfractionnumvgap  \tex_Umathfractionnumvgap:D
  \__kernel_primitive:NN \Umathfractionrule     \tex_Umathfractionrule:D
  \__kernel_primitive:NN \Umathinnerbinspacing  \tex_Umathinnerbinspacing:D
  \__kernel_primitive:NN \Umathinnerclosespacing
    \tex_Umathinnerclosespacing:D
  \__kernel_primitive:NN \Umathinnerinnerspacing
    \tex_Umathinnerinnerspacing:D
  \__kernel_primitive:NN \Umathinneropenspacing \tex_Umathinneropenspacing:D
  \__kernel_primitive:NN \Umathinneropspacing   \tex_Umathinneropspacing:D
  \__kernel_primitive:NN \Umathinnerordspacing  \tex_Umathinnerordspacing:D
  \__kernel_primitive:NN \Umathinnerpunctspacing
    \tex_Umathinnerpunctspacing:D
  \__kernel_primitive:NN \Umathinnerrelspacing  \tex_Umathinnerrelspacing:D
  \__kernel_primitive:NN \Umathlimitabovebgap   \tex_Umathlimitabovebgap:D
  \__kernel_primitive:NN \Umathlimitabovekern   \tex_Umathlimitabovekern:D
  \__kernel_primitive:NN \Umathlimitabovevgap   \tex_Umathlimitabovevgap:D
  \__kernel_primitive:NN \Umathlimitbelowbgap   \tex_Umathlimitbelowbgap:D
  \__kernel_primitive:NN \Umathlimitbelowkern   \tex_Umathlimitbelowkern:D
  \__kernel_primitive:NN \Umathlimitbelowvgap   \tex_Umathlimitbelowvgap:D
  \__kernel_primitive:NN \Umathnolimitsubfactor \tex_Umathnolimitsubfactor:D
  \__kernel_primitive:NN \Umathnolimitsupfactor \tex_Umathnolimitsupfactor:D
  \__kernel_primitive:NN \Umathopbinspacing     \tex_Umathopbinspacing:D
  \__kernel_primitive:NN \Umathopclosespacing   \tex_Umathopclosespacing:D
  \__kernel_primitive:NN \Umathopenbinspacing   \tex_Umathopenbinspacing:D
  \__kernel_primitive:NN \Umathopenclosespacing \tex_Umathopenclosespacing:D
  \__kernel_primitive:NN \Umathopeninnerspacing \tex_Umathopeninnerspacing:D
  \__kernel_primitive:NN \Umathopenopenspacing  \tex_Umathopenopenspacing:D
  \__kernel_primitive:NN \Umathopenopspacing    \tex_Umathopenopspacing:D
  \__kernel_primitive:NN \Umathopenordspacing   \tex_Umathopenordspacing:D
  \__kernel_primitive:NN \Umathopenpunctspacing \tex_Umathopenpunctspacing:D
  \__kernel_primitive:NN \Umathopenrelspacing   \tex_Umathopenrelspacing:D
  \__kernel_primitive:NN \Umathoperatorsize     \tex_Umathoperatorsize:D
  \__kernel_primitive:NN \Umathopinnerspacing   \tex_Umathopinnerspacing:D
  \__kernel_primitive:NN \Umathopopenspacing    \tex_Umathopopenspacing:D
  \__kernel_primitive:NN \Umathopopspacing      \tex_Umathopopspacing:D
  \__kernel_primitive:NN \Umathopordspacing     \tex_Umathopordspacing:D
  \__kernel_primitive:NN \Umathoppunctspacing   \tex_Umathoppunctspacing:D
  \__kernel_primitive:NN \Umathoprelspacing     \tex_Umathoprelspacing:D
  \__kernel_primitive:NN \Umathordbinspacing    \tex_Umathordbinspacing:D
  \__kernel_primitive:NN \Umathordclosespacing  \tex_Umathordclosespacing:D
  \__kernel_primitive:NN \Umathordinnerspacing  \tex_Umathordinnerspacing:D
  \__kernel_primitive:NN \Umathordopenspacing   \tex_Umathordopenspacing:D
  \__kernel_primitive:NN \Umathordopspacing     \tex_Umathordopspacing:D
  \__kernel_primitive:NN \Umathordordspacing    \tex_Umathordordspacing:D
  \__kernel_primitive:NN \Umathordpunctspacing  \tex_Umathordpunctspacing:D
  \__kernel_primitive:NN \Umathordrelspacing    \tex_Umathordrelspacing:D
  \__kernel_primitive:NN \Umathoverbarkern      \tex_Umathoverbarkern:D
  \__kernel_primitive:NN \Umathoverbarrule      \tex_Umathoverbarrule:D
  \__kernel_primitive:NN \Umathoverbarvgap      \tex_Umathoverbarvgap:D
  \__kernel_primitive:NN \Umathoverdelimiterbgap
    \tex_Umathoverdelimiterbgap:D
  \__kernel_primitive:NN \Umathoverdelimitervgap
    \tex_Umathoverdelimitervgap:D
  \__kernel_primitive:NN \Umathpunctbinspacing  \tex_Umathpunctbinspacing:D
  \__kernel_primitive:NN \Umathpunctclosespacing
    \tex_Umathpunctclosespacing:D
  \__kernel_primitive:NN \Umathpunctinnerspacing
    \tex_Umathpunctinnerspacing:D
  \__kernel_primitive:NN \Umathpunctopenspacing \tex_Umathpunctopenspacing:D
  \__kernel_primitive:NN \Umathpunctopspacing   \tex_Umathpunctopspacing:D
  \__kernel_primitive:NN \Umathpunctordspacing  \tex_Umathpunctordspacing:D
  \__kernel_primitive:NN \Umathpunctpunctspacing
    \tex_Umathpunctpunctspacing:D
  \__kernel_primitive:NN \Umathpunctrelspacing  \tex_Umathpunctrelspacing:D
  \__kernel_primitive:NN \Umathquad             \tex_Umathquad:D
  \__kernel_primitive:NN \Umathradicaldegreeafter
    \tex_Umathradicaldegreeafter:D
  \__kernel_primitive:NN \Umathradicaldegreebefore
    \tex_Umathradicaldegreebefore:D
  \__kernel_primitive:NN \Umathradicaldegreeraise
    \tex_Umathradicaldegreeraise:D
  \__kernel_primitive:NN \Umathradicalkern      \tex_Umathradicalkern:D
  \__kernel_primitive:NN \Umathradicalrule      \tex_Umathradicalrule:D
  \__kernel_primitive:NN \Umathradicalvgap      \tex_Umathradicalvgap:D
  \__kernel_primitive:NN \Umathrelbinspacing    \tex_Umathrelbinspacing:D
  \__kernel_primitive:NN \Umathrelclosespacing  \tex_Umathrelclosespacing:D
  \__kernel_primitive:NN \Umathrelinnerspacing  \tex_Umathrelinnerspacing:D
  \__kernel_primitive:NN \Umathrelopenspacing   \tex_Umathrelopenspacing:D
  \__kernel_primitive:NN \Umathrelopspacing     \tex_Umathrelopspacing:D
  \__kernel_primitive:NN \Umathrelordspacing    \tex_Umathrelordspacing:D
  \__kernel_primitive:NN \Umathrelpunctspacing  \tex_Umathrelpunctspacing:D
  \__kernel_primitive:NN \Umathrelrelspacing    \tex_Umathrelrelspacing:D
  \__kernel_primitive:NN \Umathskewedfractionhgap
    \tex_Umathskewedfractionhgap:D
  \__kernel_primitive:NN \Umathskewedfractionvgap
    \tex_Umathskewedfractionvgap:D
  \__kernel_primitive:NN \Umathspaceafterscript \tex_Umathspaceafterscript:D
  \__kernel_primitive:NN \Umathstackdenomdown   \tex_Umathstackdenomdown:D
  \__kernel_primitive:NN \Umathstacknumup       \tex_Umathstacknumup:D
  \__kernel_primitive:NN \Umathstackvgap        \tex_Umathstackvgap:D
  \__kernel_primitive:NN \Umathsubshiftdown     \tex_Umathsubshiftdown:D
  \__kernel_primitive:NN \Umathsubshiftdrop     \tex_Umathsubshiftdrop:D
  \__kernel_primitive:NN \Umathsubsupshiftdown  \tex_Umathsubsupshiftdown:D
  \__kernel_primitive:NN \Umathsubsupvgap       \tex_Umathsubsupvgap:D
  \__kernel_primitive:NN \Umathsubtopmax        \tex_Umathsubtopmax:D
  \__kernel_primitive:NN \Umathsupbottommin     \tex_Umathsupbottommin:D
  \__kernel_primitive:NN \Umathsupshiftdrop     \tex_Umathsupshiftdrop:D
  \__kernel_primitive:NN \Umathsupshiftup       \tex_Umathsupshiftup:D
  \__kernel_primitive:NN \Umathsupsubbottommax  \tex_Umathsupsubbottommax:D
  \__kernel_primitive:NN \Umathunderbarkern     \tex_Umathunderbarkern:D
  \__kernel_primitive:NN \Umathunderbarrule     \tex_Umathunderbarrule:D
  \__kernel_primitive:NN \Umathunderbarvgap     \tex_Umathunderbarvgap:D
  \__kernel_primitive:NN \Umathunderdelimiterbgap
    \tex_Umathunderdelimiterbgap:D
  \__kernel_primitive:NN \Umathunderdelimitervgap
    \tex_Umathunderdelimitervgap:D
  \__kernel_primitive:NN \Umiddle               \tex_Umiddle:D
  \__kernel_primitive:NN \Unosubscript          \tex_Unosubscript:D
  \__kernel_primitive:NN \Unosuperscript        \tex_Unosuperscript:D
  \__kernel_primitive:NN \Uoverdelimiter        \tex_Uoverdelimiter:D
  \__kernel_primitive:NN \Uradical              \tex_Uradical:D
  \__kernel_primitive:NN \Uright                \tex_Uright:D
  \__kernel_primitive:NN \Uroot                 \tex_Uroot:D
  \__kernel_primitive:NN \Uskewed               \tex_Uskewed:D
  \__kernel_primitive:NN \Uskewedwithdelims     \tex_Uskewedwithdelims:D
  \__kernel_primitive:NN \Ustack                \tex_Ustack:D
  \__kernel_primitive:NN \Ustartdisplaymath     \tex_Ustartdisplaymath:D
  \__kernel_primitive:NN \Ustartmath            \tex_Ustartmath:D
  \__kernel_primitive:NN \Ustopdisplaymath      \tex_Ustopdisplaymath:D
  \__kernel_primitive:NN \Ustopmath             \tex_Ustopmath:D
  \__kernel_primitive:NN \Usubscript            \tex_Usubscript:D
  \__kernel_primitive:NN \Usuperscript          \tex_Usuperscript:D
  \__kernel_primitive:NN \Uunderdelimiter       \tex_Uunderdelimiter:D
  \__kernel_primitive:NN \Uvextensible          \tex_Uvextensible:D
  \__kernel_primitive:NN \autospacing           \tex_autospacing:D
  \__kernel_primitive:NN \autoxspacing          \tex_autoxspacing:D
  \__kernel_primitive:NN \currentcjktoken       \tex_currentcjktoken:D
  \__kernel_primitive:NN \currentspacingmode    \tex_currentspacingmode:D
  \__kernel_primitive:NN \currentxspacingmode   \tex_currentxspacingmode:D
  \__kernel_primitive:NN \disinhibitglue        \tex_disinhibitglue:D
  \__kernel_primitive:NN \dtou                  \tex_dtou:D
  \__kernel_primitive:NN \epTeXinputencoding    \tex_epTeXinputencoding:D
  \__kernel_primitive:NN \epTeXversion          \tex_epTeXversion:D
  \__kernel_primitive:NN \euc                   \tex_euc:D
  \__kernel_primitive:NN \hfi                   \tex_hfi:D
  \__kernel_primitive:NN \ifdbox                \tex_ifdbox:D
  \__kernel_primitive:NN \ifddir                \tex_ifddir:D
  \__kernel_primitive:NN \ifjfont               \tex_ifjfont:D
  \__kernel_primitive:NN \ifmbox                \tex_ifmbox:D
  \__kernel_primitive:NN \ifmdir                \tex_ifmdir:D
  \__kernel_primitive:NN \iftbox                \tex_iftbox:D
  \__kernel_primitive:NN \iftfont               \tex_iftfont:D
  \__kernel_primitive:NN \iftdir                \tex_iftdir:D
  \__kernel_primitive:NN \ifybox                \tex_ifybox:D
  \__kernel_primitive:NN \ifydir                \tex_ifydir:D
  \__kernel_primitive:NN \inhibitglue           \tex_inhibitglue:D
  \__kernel_primitive:NN \inhibitxspcode        \tex_inhibitxspcode:D
  \__kernel_primitive:NN \jcharwidowpenalty     \tex_jcharwidowpenalty:D
  \__kernel_primitive:NN \jfam                  \tex_jfam:D
  \__kernel_primitive:NN \jfont                 \tex_jfont:D
  \__kernel_primitive:NN \jis                   \tex_jis:D
  \__kernel_primitive:NN \kanjiskip             \tex_kanjiskip:D
  \__kernel_primitive:NN \kansuji               \tex_kansuji:D
  \__kernel_primitive:NN \kansujichar           \tex_kansujichar:D
  \__kernel_primitive:NN \kcatcode              \tex_kcatcode:D
  \__kernel_primitive:NN \kuten                 \tex_kuten:D
  \__kernel_primitive:NN \lastnodechar          \tex_lastnodechar:D
  \__kernel_primitive:NN \lastnodefont          \tex_lastnodefont:D
  \__kernel_primitive:NN \lastnodesubtype       \tex_lastnodesubtype:D
  \__kernel_primitive:NN \noautospacing         \tex_noautospacing:D
  \__kernel_primitive:NN \noautoxspacing        \tex_noautoxspacing:D
  \__kernel_primitive:NN \pagefistretch         \tex_pagefistretch:D
  \__kernel_primitive:NN \postbreakpenalty      \tex_postbreakpenalty:D
  \__kernel_primitive:NN \prebreakpenalty       \tex_prebreakpenalty:D
  \__kernel_primitive:NN \ptexfontname          \tex_ptexfontname:D
  \__kernel_primitive:NN \ptexlineendmode       \tex_lineendmode:D
  \__kernel_primitive:NN \ptexminorversion      \tex_ptexminorversion:D
  \__kernel_primitive:NN \ptexrevision          \tex_ptexrevision:D
  \__kernel_primitive:NN \ptextracingfonts      \tex_ptextracingfonts:D
  \__kernel_primitive:NN \ptexversion           \tex_ptexversion:D
  \__kernel_primitive:NN \readpapersizespecial  \tex_readpapersizespecial:D
  \__kernel_primitive:NN \scriptbaselineshiftfactor
    \tex_scriptbaselineshiftfactor:D
  \__kernel_primitive:NN \scriptscriptbaselineshiftfactor
    \tex_scriptscriptbaselineshiftfactor:D
  \__kernel_primitive:NN \showmode              \tex_showmode:D
  \__kernel_primitive:NN \sjis                  \tex_sjis:D
  \__kernel_primitive:NN \tate                  \tex_tate:D
  \__kernel_primitive:NN \tbaselineshift        \tex_tbaselineshift:D
  \__kernel_primitive:NN \textbaselineshiftfactor
    \tex_textbaselineshiftfactor:D
  \__kernel_primitive:NN \tfont                 \tex_tfont:D
  \__kernel_primitive:NN \tojis                 \tex_tojis:D
  \__kernel_primitive:NN \toucs                 \tex_toucs:D
  \__kernel_primitive:NN \ucs                   \tex_ucs:D
  \__kernel_primitive:NN \xkanjiskip            \tex_xkanjiskip:D
  \__kernel_primitive:NN \xspcode               \tex_xspcode:D
  \__kernel_primitive:NN \ybaselineshift        \tex_ybaselineshift:D
  \__kernel_primitive:NN \yoko                  \tex_yoko:D
  \__kernel_primitive:NN \vfi                   \tex_vfi:D
  \__kernel_primitive:NN \disablecjktoken       \tex_disablecjktoken:D
  \__kernel_primitive:NN \enablecjktoken        \tex_enablecjktoken:D
  \__kernel_primitive:NN \forcecjktoken         \tex_forcecjktoken:D
  \__kernel_primitive:NN \kchar                 \tex_kchar:D
  \__kernel_primitive:NN \kchardef              \tex_kchardef:D
  \__kernel_primitive:NN \uptexrevision         \tex_uptexrevision:D
  \__kernel_primitive:NN \uptexversion          \tex_uptexversion:D
  \__kernel_primitive:NN \odelcode              \tex_odelcode:D
  \__kernel_primitive:NN \odelimiter            \tex_odelimiter:D
  \__kernel_primitive:NN \omathaccent           \tex_omathaccent:D
  \__kernel_primitive:NN \omathchar             \tex_omathchar:D
  \__kernel_primitive:NN \omathchardef          \tex_omathchardef:D
  \__kernel_primitive:NN \omathcode             \tex_omathcode:D
  \__kernel_primitive:NN \oradical              \tex_oradical:D
  \__kernel_primitive:NN \ignoreprimitiveerror  \tex_ignoreprimitiveerror:D
  \__kernel_primitive:NN \partokencontext       \tex_partokencontext:D
  \__kernel_primitive:NN \partokenname          \tex_partokenname:D
  \__kernel_primitive:NN \showstream            \tex_showstream:D
  \__kernel_primitive:NN \tracingstacklevels    \tex_tracingstacklevels:D
%% 
%%
%% End of file `l3names.def'.
